.. _support:

Support
=======

If you have questions or issues about Requests, there are several options:

Send a Tweet
------------

If your question is less than 140 characters, feel free to send a tweet to
`@kennethreitz <http://twitter.com/kennethreitz>`_.


File an Issue
-------------

If you notice some unexpected behavior in Requests, or want to see support
for a new feature,
`file an issue on GitHub <https://github.com/kennethreitz/requests/issues>`_.


E-mail
------

I'm more than happy to answer any personal or in-depth questions about
Requests. Feel free to email
`requests@kennethreitz.com <mailto:requests@kennethreitz.com>`_.


IRC
---

The official Freenode channel for Requests is
`#python-requests <irc://irc.freenode.net/python-requests>`_

I'm also available as **kennethreitz** on Freenode.
